==> qtjambi-remoteobjects-5.15.11-sources.jar: io/qt/remoteobjects/QRemoteObjectSourceLocationInfo.java <==
package io.qt.remoteobjects;


/**
 * <p>Java wrapper for Qt class QRemoteObjectSourceLocationInfo</p>
 */
public class QRemoteObjectSourceLocationInfo extends io.qt.QtObject
    implements java.lang.Cloneable
{
    static {
        QtJambi_LibraryUtilities.initialize();
    }
    
    
    public QRemoteObjectSourceLocationInfo(){
        super((QPrivateConstructor)null);
        initialize_native(this);
    }
    
    private native static void initialize_native(QRemoteObjectSourceLocationInfo instance);
    
    public QRemoteObjectSourceLocationInfo(java.lang.String typeName_, io.qt.core.QUrl hostUrl_){
        super((QPrivateConstructor)null);
        initialize_native(this, typeName_, hostUrl_);
    }
    
    private native static void initialize_native(QRemoteObjectSourceLocationInfo instance, java.lang.String typeName_, io.qt.core.QUrl hostUrl_);
    
    @io.qt.QtUninvokable
    public void writeTo(io.qt.core.QDataStream stream){
        java.util.Objects.requireNonNull(stream, "Argument 'stream': null not expected.");
        writeTo_native_ref_QDataStream(QtJambi_LibraryUtilities.internal.nativeId(this), QtJambi_LibraryUtilities.internal.checkedNativeId(stream));
    }
    
    @io.qt.QtUninvokable
    private native void writeTo_native_ref_QDataStream(long __this__nativeId, long stream);
    
    @io.qt.QtUninvokable
    private final boolean operator_equal(io.qt.remoteobjects.QRemoteObjectSourceLocationInfo other){
        return operator_equal_native_cref_QRemoteObjectSourceLocationInfo_constfct(QtJambi_LibraryUtilities.internal.nativeId(this), QtJambi_LibraryUtilities.internal.checkedNativeId(other));
    }
    
    @io.qt.QtUninvokable
    private native boolean operator_equal_native_cref_QRemoteObjectSourceLocationInfo_constfct(long __this__nativeId, long other);
    
    @io.qt.QtUninvokable
    public void readFrom(io.qt.core.QDataStream stream){
        java.util.Objects.requireNonNull(stream, "Argument 'stream': null not expected.");
        readFrom_native_ref_QDataStream(QtJambi_LibraryUtilities.internal.nativeId(this), QtJambi_LibraryUtilities.internal.checkedNativeId(stream));
    }
    
    @io.qt.QtUninvokable
    private native void readFrom_native_ref_QDataStream(long __this__nativeId, long stream);
    
    @io.qt.QtUninvokable
    public final void setHostUrl(io.qt.core.QUrl hostUrl){
        setHostUrl_native_cref_QUrl(QtJambi_LibraryUtilities.internal.nativeId(this), QtJambi_LibraryUtilities.internal.checkedNativeId(hostUrl));
    }
    
    @io.qt.QtUninvokable
    private native void setHostUrl_native_cref_QUrl(long __this__nativeId, long hostUrl);
    
    @io.qt.QtUninvokable
    public final io.qt.core.QUrl hostUrl(){
        return hostUrl_native(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    @io.qt.QtUninvokable
    private native io.qt.core.QUrl hostUrl_native(long __this__nativeId);
    
    @io.qt.QtUninvokable
    public final void setTypeName(java.lang.String typeName){
        setTypeName_native_cref_QString(QtJambi_LibraryUtilities.internal.nativeId(this), typeName);
    }
    
    @io.qt.QtUninvokable
    private native void setTypeName_native_cref_QString(long __this__nativeId, java.lang.String typeName);
    
    @io.qt.QtUninvokable
    public final java.lang.String typeName(){
        return typeName_native(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    @io.qt.QtUninvokable
    private native java.lang.String typeName_native(long __this__nativeId);
    
    /**
     * Constructor for internal use only.
     * @param p expected to be <code>null</code>.
     */
    @io.qt.NativeAccess
    protected QRemoteObjectSourceLocationInfo(QPrivateConstructor p) { super(p); } 
    

    @Override
    @io.qt.QtUninvokable
    public boolean equals(Object other) {
        if (other instanceof io.qt.remoteobjects.QRemoteObjectSourceLocationInfo) {
            return operator_equal((io.qt.remoteobjects.QRemoteObjectSourceLocationInfo) other);
        }

        return false;
    }


    @io.qt.QtUninvokable
    @Override
    public int hashCode() {
        return hashCode_native(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    @io.qt.QtUninvokable
    private native static int hashCode_native(long __this_nativeId);

    @Override
    @io.qt.QtUninvokable
    public String toString() {
        return toString_native(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    @io.qt.QtUninvokable
    private static native String toString_native(long __this_nativeId);
    
    @Override
    public QRemoteObjectSourceLocationInfo clone() {
        return clone_native(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    private native QRemoteObjectSourceLocationInfo clone_native(long __this_nativeId);
}

==> qtjambi-remoteobjects-5.15.14-sources.jar: io/qt/remoteobjects/QRemoteObjectSourceLocationInfo.java <==
package io.qt.remoteobjects;

import io.qt.*;


/**
 * <p>Java wrapper for Qt class QRemoteObjectSourceLocationInfo</p>
 */
public class QRemoteObjectSourceLocationInfo extends QtObject
    implements java.lang.Cloneable
{
    static {
        QtJambi_LibraryUtilities.initialize();
    }
    
    
    public QRemoteObjectSourceLocationInfo(){
        super((QPrivateConstructor)null);
        initialize_native(this);
    }
    
    private native static void initialize_native(QRemoteObjectSourceLocationInfo instance);
    
    public QRemoteObjectSourceLocationInfo(java.lang.@NonNull String typeName_, io.qt.core.@NonNull QUrl hostUrl_){
        super((QPrivateConstructor)null);
        initialize_native(this, typeName_, hostUrl_);
    }
    
    private native static void initialize_native(QRemoteObjectSourceLocationInfo instance, java.lang.String typeName_, io.qt.core.QUrl hostUrl_);
    
    @QtUninvokable
    public void writeTo(io.qt.core.@StrictNonNull QDataStream stream){
        java.util.Objects.requireNonNull(stream, "Argument 'stream': null not expected.");
        writeTo_native_ref_QDataStream(QtJambi_LibraryUtilities.internal.nativeId(this), QtJambi_LibraryUtilities.internal.checkedNativeId(stream));
    }
    
    @QtUninvokable
    private native void writeTo_native_ref_QDataStream(long __this__nativeId, long stream);
    
    @QtUninvokable
    private final boolean operator_equal(io.qt.remoteobjects.@NonNull QRemoteObjectSourceLocationInfo other){
        return operator_equal_native_cref_QRemoteObjectSourceLocationInfo_constfct(QtJambi_LibraryUtilities.internal.nativeId(this), QtJambi_LibraryUtilities.internal.checkedNativeId(other));
    }
    
    @QtUninvokable
    private native boolean operator_equal_native_cref_QRemoteObjectSourceLocationInfo_constfct(long __this__nativeId, long other);
    
    @QtUninvokable
    public void readFrom(io.qt.core.@StrictNonNull QDataStream stream){
        java.util.Objects.requireNonNull(stream, "Argument 'stream': null not expected.");
        readFrom_native_ref_QDataStream(QtJambi_LibraryUtilities.internal.nativeId(this), QtJambi_LibraryUtilities.internal.checkedNativeId(stream));
    }
    
    @QtUninvokable
    private native void readFrom_native_ref_QDataStream(long __this__nativeId, long stream);
    
    @QtUninvokable
    public final void setHostUrl(io.qt.core.@NonNull QUrl hostUrl){
        setHostUrl_native_cref_QUrl(QtJambi_LibraryUtilities.internal.nativeId(this), QtJambi_LibraryUtilities.internal.checkedNativeId(hostUrl));
    }
    
    @QtUninvokable
    private native void setHostUrl_native_cref_QUrl(long __this__nativeId, long hostUrl);
    
    /**
     * <p>Kotlin property getter. In Java use {@link #hostUrl()} instead.</p>
     */
    @QtUninvokable
    public final io.qt.core.@NonNull QUrl getHostUrl() {
        return hostUrl();
    }
    
    @QtUninvokable
    public final io.qt.core.@NonNull QUrl hostUrl(){
        return hostUrl_native(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    @QtUninvokable
    private native io.qt.core.QUrl hostUrl_native(long __this__nativeId);
    
    @QtUninvokable
    public final void setTypeName(java.lang.@NonNull String typeName){
        setTypeName_native_cref_QString(QtJambi_LibraryUtilities.internal.nativeId(this), typeName);
    }
    
    @QtUninvokable
    private native void setTypeName_native_cref_QString(long __this__nativeId, java.lang.String typeName);
    
    /**
     * <p>Kotlin property getter. In Java use {@link #typeName()} instead.</p>
     */
    @QtUninvokable
    public final java.lang.@NonNull String getTypeName() {
        return typeName();
    }
    
    @QtUninvokable
    public final java.lang.@NonNull String typeName(){
        return typeName_native(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    @QtUninvokable
    private native java.lang.String typeName_native(long __this__nativeId);
    
    /**
     * Constructor for internal use only.
     * @param p expected to be <code>null</code>.
     */
    @NativeAccess
    protected QRemoteObjectSourceLocationInfo(QPrivateConstructor p) { super(p); } 
    

    @Override
    @QtUninvokable
    public boolean equals(Object other) {
        if (other instanceof io.qt.remoteobjects.QRemoteObjectSourceLocationInfo) {
            return operator_equal((io.qt.remoteobjects.QRemoteObjectSourceLocationInfo) other);
        }

        return false;
    }


    @QtUninvokable
    @Override
    public int hashCode() {
        return hashCode_native(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    @QtUninvokable
    private native static int hashCode_native(long __this_nativeId);

    @Override
    @QtUninvokable
    public @NonNull String toString() {
        return toString_native(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    @QtUninvokable
    private static native String toString_native(long __this_nativeId);
    
    @QtUninvokable
    @Override
    public QRemoteObjectSourceLocationInfo clone() {
        return clone_native(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    private static native QRemoteObjectSourceLocationInfo clone_native(long __this_nativeId);
}
